SeaPy - Superposed Epoch in Python — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »

# SeaPy - Superposed Epoch in Python

SeaPy – Superposed Epoch in Python.

This module contains superposed epoch class types and a variety of functions for using on superposed epoch objects. Each instance must be initialized with (assuming import seapy as se):

    >>> obj = se.Sea(data, times, epochs)

To perform a superposed epoch analysis

    >>> obj.sea()

To plot

    >>> obj.plot()

If multiple SeaPy objects exist, these can be combined into a single object

    >>> objdict = seadict([obj1, obj2],['obj1name','obj2name'])

and then used to create a multipanel plot

    >>> multisea(objdict)

For two-dimensional superposed epoch analyses, initialize an Sea2d() instance

    >>> obj = se.Sea2d(data, times, epochs, y=[4., 12.])

All object methods are the same as for the 1D object. Also, the multisea() function should accept both 1D and 2D objects, even mixed together. Currently, the plot() method is recommended for 2D SEA.

–++– By Steve Morley –++–

smorley@lanl.gov Los Alamos National Laboratory

Copyright 2010 Los Alamos National Security, LLC.

Classes

`Sea`(data, times, epochs[, window, delta, ...]) | SeaPy Superposed epoch analysis object
`Sea2d`(data, times, epochs[, window, delta, ...]) | SeaPy 2D Superposed epoch analysis object

Functions

`seadict`(objlist, namelist) | Function to create dictionary of SeaPy.Sea objects.
`multisea`(dictobj[, n_cols, epochline, ...]) | Function to create multipanel plot of superposed epoch analyses.
`readepochs`(fname[, iso, isofmt]) | Read epochs from text file assuming YYYY MM DD hh mm ss format
`sea_signif`(obj1, obj2[, test, show, xquan, ...]) | Test for similarity between distributions at each lag in two 1-D SEAs

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »